==> tine20-allinone_2019.12.5.tar.bz2: Filemanager/js/Filemanager-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Upload Failed"
: "Carga Fallida"

, "Putting files in this folder is not allowed!"
: "No está permitido poner archivos en esta carpeta!"

, "Filemanager"
: "Gestor de archivos"

, "Save locally"
: "Guardar localmente"

, "Tags"
: "Etiquetas"

, "Name"
: "Nombre"

, "Size"
: "Tamaño"

, "Contenttype"
: "Tipo de contenido"

, "Folder, Folders"
: [
  "Carpeta"
 ,"Carpetas"

]
, "Creation Time"
: "Fecha de Creación"

, "Created By"
: "Creado por"

, "Last Modified Time"
: "Fecha última modificación"

, "Last Modified By"
: "Última modificación por"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Subir"

, "Open Data Safe"
: ""

, "Folder Up"
: "Subir Carpeta"

, "Close Data Safe"
: ""

, "Node Download Links"
: ""

, "Url"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Service Unavailable"
: "Servicio no disponible"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "El gestor de archivos no está configurado correctamente. Por favor, consulte el {0} Tine 2.0 Administrador FAQ {1} para obtener consejo de configuración o póngase en contacto con su administrador."

, "Files already exists"
: "Los archivos ya existen"

, "Do you want to replace the following file(s)?"
: "¿Realmente desea reemplazarlo(s)?"

, "Failure on create folder"
: "Fallo al crear carpeta"

, "Item with this name already exists!"
: "Existe un item con el mismo nombre!"

, "Revision"
: "Revisión"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "path"
: "Ruta"

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Reload"
: ""

, "Create Folder"
: "Crear Carpeta"

, "New Folder"
: "Nueva Carpeta"

, "Please enter the name of the new folder:"
: "Por favor introduzca el nombre de la nueva carpeta:"

, "No {0} added"
: "No {0} agregado"

, "You have to supply a {0} name!"
: "¡Ud. debe ingresar {0} nombre!"

, "Edit Properties"
: "Editar Propiedades"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Por favor introduce un nuevo nombre para {0}:"

, "Not renamed {0}"
: "{0} no renombrado"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Borrar"

, "Do you really want to delete the following files?"
: "¿Realmente desea borrar los archivos seleccionados?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Publish"
: ""

, "Public download links can be password protected. If left blank anyone who knows the link can download the selected files."
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "File, Files"
: [
  "Fichero"
 ,"Ficheros"

]
, "The grant to download files"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Copiando datos .. {0}"

, "Moving data .. {0}"
: "Moviendo datos .. {0}"

, "Please wait"
: "Por favor espere"

, "Quick Search"
: "Búsqueda Rápida"

, "Type"
: "Tipo"

, "Description"
: "Descripción"

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Grants"
: ""

, "This folder has own grants"
: ""

, "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
: ""

, "This folder is part of the data safe"
: ""

, "If data safe protection is enabled, this folder and all it's contents is only shown if the data safe is opened."
: ""

, "Sorry, Tine 2.0 would like to show you the contents of the file displayed."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We are happy make you a non-binding offer."
: ""

, "No preview available."
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Remove record"
: ""

, "Search for groups ..."
: ""

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: ""

, "Not yet indexed"
: ""

, "Modified By"
: "Modificado por"

, "Last Modified"
: "Última modificación"

, "Enter description"
: "Introducir descripción"

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Create Public Link"
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Usage"
: ""

, "The Quota applies recursively for files and subfolders. Please note, the Effective Quota differs wehn a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "Row double click default"
: ""

, "Defines which action should be executed on double click by default?"
: ""

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Public Download URL"
: ""

, "Serve anonymous downloads from a different URL. Make sure to setup proper rewrite rules."
: ""

, "manage shared folders"
: "gestionar carpetas compartidas"

, "Create new shared folders"
: "Crear nueva carpeta compartida"

, "Manage anonymous download links"
: ""

, "Allow to see, add and delete download links of files and folders"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path the source has. No action has been performed."
: ""

, "My folders"
: "Mis carpetas"

, "Shared folders"
: "Carpetas compartidas"

, "Other users folders"
: "Otras carpetas de usuarios"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Folder"
: "Carpeta"

, "File"
: "Fichero"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Filemanager/js/Filemanager-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Name"
: "Nombre"

, "Size"
: "Tamaño"

, "Last Modified"
: "Última modificación"

, "Description"
: "Descripción"

, "Folder, Folders"
: [
  "Carpeta"
 ,"Carpetas"

]
, "File, Files"
: [
  "Fichero"
 ,"Ficheros"

]
, "Default behavior when double-clicking on a Row"
: ""

, "Defines which action should be executed by default when double-clicked."
: ""

, "Invalid Filename"
: ""

, "Content type"
: ""

, "path"
: "Ruta"

, "URL"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Create Public Link"
: ""

, "Remove record"
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Created By"
: "Creado por"

, "Creation Time"
: "Fecha de Creación"

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "Fecha última modificación"

, "Last Modified By"
: "Última modificación por"

, "Revision"
: "Revisión"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "Upload Failed"
: "Carga Fallida"

, "It is not permitted to store files in this folder!"
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Tags"
: "Etiquetas"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Subir"

, "Open Data Safe"
: ""

, "Folder Up"
: "Subir Carpeta"

, "Close Data Safe"
: ""

, "Filemanager"
: "Gestor de archivos"

, "Save locally"
: "Guardar localmente"

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: ""

, "Type"
: "Tipo"

, "Not yet indexed"
: ""

, "Modified By"
: "Modificado por"

, "Enter description"
: "Introducir descripción"

, "Service Unavailable"
: "Servicio no disponible"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "El gestor de archivos no está configurado correctamente. Por favor, consulte el {0} Tine 2.0 Administrador FAQ {1} para obtener consejo de configuración o póngase en contacto con su administrador."

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "¿Realmente desea reemplazarlo(s)?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "Existe un item con el mismo nombre!"

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "The grant to download files"
: ""

, "Publish"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Copiando datos .. {0}"

, "Moving data .. {0}"
: "Moviendo datos .. {0}"

, "Please wait"
: "Por favor espere"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Quick Search"
: "Búsqueda Rápida"

, "Content Type"
: ""

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Node Download Links"
: ""

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Reload"
: ""

, "Create Folder"
: "Crear Carpeta"

, "New Folder"
: "Nueva Carpeta"

, "Please enter the name of the new folder:"
: "Por favor introduzca el nombre de la nueva carpeta:"

, "No {0} added"
: "No {0} agregado"

, "You have to supply a {0} name!"
: "¡Ud. debe ingresar {0} nombre!"

, "Edit Properties"
: "Editar Propiedades"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Por favor introduce un nuevo nombre para {0}:"

, "Not renamed {0}"
: "{0} no renombrado"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Borrar"

, "Do you really want to delete the following files?"
: "¿Realmente desea borrar los archivos seleccionados?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Mis carpetas"

, "Shared folders"
: "Carpetas compartidas"

, "Other users folders"
: "Otras carpetas de usuarios"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "manage shared folders"
: "gestionar carpetas compartidas"

, "Create new shared folders"
: "Crear nueva carpeta compartida"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""





, "Folder"
: "Carpeta"

, "File"
: "Fichero"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
